@@ -99,6 +99,12 @@ class Simuwater:
     def simuwater_setSetting(self, obj_id, setting_value):
         return self._simuwater.simuwater_setSetting(obj_id.encode('utf-8'),
                                                     ctypes.c_double(setting_value))
+        
+    def simuwater_getSetting(self, obj_id):
+        setting_value = ctypes.c_double()
+        self._simuwater.simuwater_getSetting(obj_id.encode('utf-8'),
+                                             ctypes.byref(setting_value))
+        return setting_value.value
     
     def simuwater_getResult(self, obj_type, obj_id, var_type):
         result_value = ctypes.c_double()
@@ -106,7 +112,41 @@ class Simuwater:
                                                        obj_id.encode('utf-8'),
                                                        ctypes.c_int(var_type),
                                                        ctypes.byref(result_value))
-        return err_code, result_value.value
+        return result_value.value
+    
+    def simuwater_getParam(self, obj_type, obj_id, param_type):
+        result_value = ctypes.c_double()
+        self._simuwater.simuwater_getParam(ctypes.c_int(obj_type),
+                                                      obj_id.encode('utf-8'),
+                                                      ctypes.c_int(param_type),
+                                                      ctypes.byref(result_value))
+        return result_value.value
+    
+    def simuwater_setParam(self, obj_type, obj_id, param_type, value):
+        return self._simuwater.simuwater_setParam(ctypes.c_int(obj_type),
+                                                  obj_id.encode('utf-8'),
+                                                  ctypes.c_int(param_type),
+                                                  ctypes.c_double(value))
+    
+    def simuwater_setTankDepth(self, obj_id, value):
+        return self._simuwater.simuwater_setTankDepth(obj_id.encode('utf-8'),
+                                                      ctypes.c_double(value))
+        
+    def simuwater_setLinkFlow(self, obj_id, value):
+        return self._simuwater.simuwater_setLinkFlow(obj_id.encode('utf-8'),
+                                                     ctypes.c_double(value))
+        
+    def simuwater_getNodeType(self, obj_id):
+        node_type = ctypes.c_int()
+        self._simuwater.simuwater_getNodeType(obj_id.encode('utf-8'),
+                                                     ctypes.byref(node_type))
+        return node_type.value
+    
+    def simuwater_getLinkType(self, obj_id):
+        link_type = ctypes.c_int()
+        self._simuwater.simuwater_getLinkType(obj_id.encode('utf-8'),
+                                                     ctypes.byref(link_type))
+        return link_type.value
     
     def simuwater_setSwmmExtInflow(self, inp_id, obj_id, extInflow):
         return self._simuwater.simuwater_setSwmmExtInflow(inp_id.encode('utf-8'),
@@ -181,18 +221,18 @@ class Simuwater:
                                                           ctypes.c_int(param_type), 
                                                           ctypes.c_double(value))
         
-    def simuuwater_setSwmmNodeDepth(self, inp_id, obj_id, value):
-        return self._simuwater_setSwmmNodeDepth(inp_id.encode('utf-8'),
+    def simuwater_setSwmmNodeDepth(self, inp_id, obj_id, value):
+        return self._simuwater.simuwater_setSwmmNodeDepth(inp_id.encode('utf-8'),
                                                 obj_id.encode('utf-8'),
                                                 ctypes.c_double(value))
     
-    def simuuwater_setSwmmLinkDepth(self, inp_id, obj_id, value):
-        return self._simuwater_setSwmmLinkDepth(inp_id.encode('utf-8'),
+    def simuwater_setSwmmLinkDepth(self, inp_id, obj_id, value):
+        return self._simuwater.simuwater_setSwmmLinkDepth(inp_id.encode('utf-8'),
                                                 obj_id.encode('utf-8'),
                                                 ctypes.c_double(value))
         
-    def simuuwater_setSwmmLinkFlow(self, inp_id, obj_id, value):
-        return self._simuwater_setSwmmLinkFlow(inp_id.encode('utf-8'),
+    def simuwater_setSwmmLinkFlow(self, inp_id, obj_id, value):
+        return self._simuwater.simuwater_setSwmmLinkFlow(inp_id.encode('utf-8'),
                                                 obj_id.encode('utf-8'),
                                                 ctypes.c_double(value))
     
